@@ -1,6 +1,6 @@
 # Samizdat view management class
 #
-#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2011  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -15,7 +15,7 @@ class View
   def initialize(site, template)
     location = find_file(template, site.config['templates'])
     location or raise RuntimeError,
-      "Template not found: '#{CGI.escapeHTML(template)}'"
+      "Template not found: '#{Rack::Utils.escape_html(template)}'"
     set_renderer(location)
   end
 
